# aio9p

Asyncio-based bindings for the 9P protocol. Work in progress.

Working examples for the 9P2000 9P2000.u dialects are implemented in aio9p.example .

# TODO

## Features
- Support for the 9P2000.L dialect
- Message generation and parsing from the client perspective

## Testing
- Significantly expanded unit testing
- Integration tests
- Benchmarking
